#!/bin/bash

# Cleans up all the installed ans setup assets during the setup phase of the SIM
# usage: 
# ./cleanup.sh -r
# When -r is provided mysql will be completely removed from the OS

RED='\033[0;31m'
GREEN='\033[0;32m'
CYAN="\033[0;36m"
NC='\033[0m'

printf "\n${GREEN}Welcome to SIM cleanup script.${NC}\n\n"
echo "================================" >> setup.log 2>&1
echo "CLEANUP STARTED" >> setup.log 2>&1

tmp=$(grep -i ubuntu /etc/os-release)
if [ $? -eq 0 ]; then
   web_server="apache2"
   distro="Ubuntu"
else
   web_server="httpd"
   distro="RHEL"
fi

remove=$1

mysql -u root <<-EOF
USE mysql;
DROP DATABASE sim2;
DROP USER 'sim'@'localhost';
DROP DATABASE db_saus_client;
DROP USER 'saus'@'localhost';
FLUSH PRIVILEGES;
EOF
printf "${CYAN}Stopping services.${NC}\n"
service sim stop >> setup.log 2>&1
service  saus stop >> setup.log 2>&1
service etcd stop >> setup.log 2>&1
systemctl stop mysql >> setup.log 2>&1
systemctl stop mysqld >> setup.log 2>&1
systemctl stop apache2 >> setup.log 2>&1
systemctl stop httpd >> setup.log 2>&1

if [ "$remove" = "-r" ]; then
    printf "${CYAN}Removing packages.${NC}\n"
    if [ "$distro" = "Ubuntu" ]; then
        apt-get purge -y apache2 >> setup.log 2>&1
        rm -rf /etc/apache2 >> setup.log 2>&1
        apt purge -y mysql-server mysql-client mariadb-server mariadb-client mysql-common mysql-server-core-* mysql-client-core-* >> setup.log 2>&1
        apt-get purge -y docker >> setup.log 2>&1
    else
        dnf remove -y httpd.x86_64 >> setup.log 2>&1
        rm -rf /etc/httpd >> setup.log 2>&1
        dnf remove -y mysql-server mysql-client mariadb-server mariadb-client mysql-common mysql-server-core-* mysql-client-core-* >> setup.log 2>&1
        dnf remove -y docker >> setup.log 2>&1
    fi
    rm -rf /etc/mysql /var/lib/mysql /var/log/mysql >> setup.log 2>&1
    rm /root/.my.cnf >> setup.log 2>&1
fi


printf "${CYAN}Removing files and configuration.${NC}\n"
if [ "$distro" = "RHEL" ]; then   
    sed -i "s/LoadModule proxy_module modules\/mod_proxy.so//" /etc/httpd/conf/httpd.conf >> setup.log 2>&1
    sed -i "s/LoadModule proxy_connect_module modules\/mod_proxy_connect.so//" /etc/httpd/conf/httpd.conf >> setup.log 2>&1
    sed -i "s/LoadModule proxy_balancer_module modules\/mod_proxy_balancer.so//" /etc/httpd/conf/httpd.conf >> setup.log 2>&1
    sed -i "s/LoadModule proxy_http_module modules\/mod_proxy_http.so//" /etc/httpd/conf/httpd.conf >> setup.log 2>&1
    sed -i "s/LoadModule rewrite_module modules\/mod_rewrite.so//" /etc/httpd/conf/httpd.conf >> setup.log 2>&1
    sed -i "s/LoadModule deflate_module modules\/mod_deflate.so//" /etc/httpd/conf/httpd.conf >> setup.log 2>&1
    sed -i "s/LoadModule headers_module modules\/mod_headers.so//" /etc/httpd/conf/httpd.conf >> setup.log 2>&1
    sed -i "s/LoadModule proxy_wstunnel_module modules\/mod_proxy_wstunnel.so//" /etc/httpd/conf/httpd.conf >> setup.log 2>&1
    sed -i "s/IncludeOptional sites-enabled\/*.conf//" /etc/httpd/conf/httpd.conf >> setup.log 2>&1
    sed -i "s/Listen .*//g"  /etc/httpd/conf/httpd.conf >> setup.log 2>&1
fi

default_user="sim-user"
userdel -r -f $default_user >> setup.log 2>&1
sed -i "s/$default_user ALL=(ALL) NOPASSWD:ALL//" /etc/sudoers >> setup.log 2>&1

rm -r /etc/$web_server/sites-enabled >> setup.log 2>&1
rm -r /etc/$web_server/sites-available >> setup.log 2>&1
rm -r /var/www/html/* >> setup.log 2>&1
rm /etc/systemd/system/sim.service >> setup.log 2>&1
rm /etc/init.d/sim >> setup.log 2>&1
rm /etc/sim-api.conf >> setup.log 2>&1
rm /var/log/sim/log >> setup.log 2>&1
rm /etc/logrotate.d/sim_api_logrotate >> setup.log 2>&1
rm /etc/logrotate.d/saus_logrotate >> setup.log 2>&1
rm /usr/local/bin/saus-client >> setup.log 2>&1
rm /etc/systemd/system/saus.service >> setup.log 2>&1

rm /etc/init.d/sim >> setup.log 2>&1
rm /etc/systemd/system/sim.service >> setup.log 2>&1
rm /lib/systemd/system/saus.service >> setup.log 2>&1
rm /etc/systemd/system/ >> setup.log 2>&1
systemctl restart $web_server >> setup.log 2>&1

rm /lib/systemd/system/etcd.service
rm /etc/systemd/system/etcd.service
rm /usr/local/bin/etcd
rm /usr/local/bin/etcdctl

cp /etc/fstab /etc/fstab.bak
sed -i '/\/swapfile/d' /etc/fstab
swapoff -a -v
rm /swapfile

echo "CLEANUP COMPLETED" >> setup.log 2>&1
echo "================================" >> setup.log 2>&1
# All Finished
printf "${GREEN}\n"
printf " - ALL DONE - \n"
printf "\n${NC}"
