#!/bin/bash
# Run this script using
# ./add_secure_domain.sh domain email

# requirements: apache/httpd, certbot, /etc/web-server/sites-available/sim2.conf
# a configured domain name
exec >> ./secure_domain.log 2>&1
echo "===================================================================================================="

domain=$1
email=$2
if [ -z "$domain" ]
    then
        timestamp=$( date +%T )
        echo "$timestamp - First argument - domain not supplied"
        exit 1
fi

if [ -z "$email" ]
    then
        timestamp=$( date +%T )
        echo "$timestamp - Second argument - email not supplied"
        exit 1
fi

timestamp=$( date +%T )
echo "$timestamp - add_secure_domain has started for domain $domain and email $email"

tmp=$(grep -i ubuntu /etc/os-release)
if [ $? -eq 0 ]; then
   web_server="apache2"
else
   web_server="httpd"
fi

# exit when any command fails
set -e

sudo rm /etc/$web_server/sites-enabled/sim2.conf
echo "disable sim2.conf response status: " $?

sudo cp /etc/$web_server/sites-available/sim2.conf /etc/$web_server/sites-available/$domain.conf
sudo sed -i "s/#%SERVER_NAME%/ServerName $domain/" /etc/$web_server/sites-available/$domain.conf

# Enable conf for new domain
sudo ln -s /etc/$web_server/sites-available/$domain.conf /etc/$web_server/sites-enabled/$domain.conf
echo "enable domain conf response status: " $?

# run certbot and autorenew
sudo certbot --apache -n -d $domain --redirect --agree-tos --email $email
echo "certbot response: " $?
#ignore possible error of auto renew
set +e
sudo certbot renew --dry-run
echo "certbot renew response: " $?
set -e

if [ "$web_server" = "httpd" ]; then
  ln -s /etc/$web_server/sites-available/$domain.conf /etc/$web_server/sites-enabled/$domain-le-ssl.conf
fi

# start web server
sudo service $web_server reload

echo "add_secure_domain has finished"
