#!/bin/bash

# Run this script using
# ./expose_cluster.sh cluster_port expose_port template_conf_file

exec >> ./expose_cluster.log 2>&1
echo "===================================================================================================="

cluster_port=$1
expose_port=$2
template_conf_file=$3

if [ -z "$cluster_port" ]
    then
        timestamp=$( date +%T )
        echo "$timestamp - First argument - cluster port not supplied"
        exit 1
fi

if [ -z "$expose_port" ]
    then
        timestamp=$( date +%T )
        echo "$timestamp - Second argument - expose port not supplied"
        exit 1
fi

if [ -z "$template_conf_file" ]
    then
        timestamp=$( date +%T )
        echo "$timestamp - Third argument - template conf file path not supplied"
        exit 1
fi

timestamp=$( date +%T )
echo "$timestamp - Starting to expose cluster from port $cluster_port to $expose_port"

tmp=$(grep -i ubuntu /etc/os-release)
if [ $? -eq 0 ]; then
   web_server="apache2"
else
   web_server="httpd"
fi

conf_file="cluster-$cluster_port.conf"
sudo cp /etc/$web_server/sites-available/$template_conf_file /etc/$web_server/sites-available/$conf_file
timestamp=$( date +%T )
echo "$timestamp - Created conf file at /etc/$web_server/sites-available/$conf_file"

sudo sed -i "s/%OUT_PORT%/$expose_port/" /etc/$web_server/sites-available/$conf_file
sudo sed -i "s/%CLUSTER_PORT%/$cluster_port/" /etc/$web_server/sites-available/$conf_file
timestamp=$( date +%T )
echo "$timestamp - Updated $conf_file"

sudo ln -s /etc/$web_server/sites-available/$conf_file /etc/$web_server/sites-enabled/$conf_file
timestamp=$( date +%T )
echo "$timestamp - Enabled $conf_file"

if [ "$web_server" = "httpd" ]; then
  sed -i "s/Listen .*//g" /etc/$web_server/sites-available/$conf_file
  echo "Listen $expose_port" >> /etc/httpd/conf/httpd.conf
  semanage port -a -t http_port_t -p tcp $expose_port || true
  semanage port -a -t http_port_t -p udp $expose_port || true
fi

sudo service $web_server reload
timestamp=$( date +%T )
echo "$timestamp - $web_server reloaded"

timestamp=$( date +%T )
echo "$timestamp - Finished to expose cluster from port $cluster_port to $expose_port using $conf_file"
