#!/bin/bash

# Run this script using
# ./restore_dbs.sh /path/to/backup.tar.gz /temp/path/for/files

exec >> ./restore_db.log 2>&1
echo "===================================================================================================="

# the SQL file and the hash bundled into a tarball
BACKUP_FILE=$1
if [ -z "$BACKUP_FILE" ]
    then
        timestamp=$( date +%T )
        echo "$timestamp - First argument - backup file name not supplied"
        exit 1
fi

BACKUP_FOLDER=$2
if [ -z "$BACKUP_FOLDER" ]
    then
        timestamp=$( date +%T )
        echo "$timestamp - Second argument -  local backup location not supplied"
        exit 1
fi

timestamp=$( date +%T )
echo "$timestamp - Restoring the DB based on the backup $BACKUP_FILE"

timestamp=$( date +%T )
echo "$timestamp - Stopping sim2"
#stop sim2

timestamp=$( date +%T )
echo "$timestamp - Dropping databases"
mysql -e -uroot "drop database sim2;"

timestamp=$( date +%T )
echo "$timestamp - Restoring database"

timestamp=$( date +%T )
echo "$timestamp - Copy file to backup folder"
cp $BACKUP_FILE $BACKUP_FOLDER

# Now extract the base backup name
BASE_BACKUP_NAME=`echo "$BACKUP_FILE" | awk -F'[.]' '{print $1}'`

# Uncompress the BACKUP_FILE in the backup folder
timestamp=$( date +%T )
echo "$timestamp - Uncompress the backup file"
tar -zxvf $BACKUP_FILE --directory $BACKUP_FOLDER

# Extract the sql backup file name
timestamp=$( date +%T )
BASE_SQL_DB_FILE_NAME=`echo $BASE_BACKUP_NAME | awk -F'[/]' '{print $4}'`.sql.gz
SQL_DB_FILE_NAME=$BACKUP_FOLDER/$BASE_SQL_DB_FILE_NAME

echo "$timestamp - Extracted the sql backup file name as $SQL_DB_FILE_NAME"
zcat $SQL_DB_FILE_NAME | mysql -uroot

timestamp=$( date +%T )
echo "$timestamp - Removing backup file and hash"
rm -f $SQL_DB_FILE_NAME*
echo "$timestamp - Result $?"


timestamp=$( date +%T )
echo "$timestamp - Restarting mysql"
# sudo /etc/init.d/mysql restart

timestamp=$( date +%T )
echo "$timestamp - Starting sim2"
# start sim2
